@@ -164,6 +164,9 @@ class LPMain:
         # Transfer the optimization problem to the Gurobi API.
         # Create an empty problem
         problem = gp.Model()
+        if self.inputdata.verbose == False:
+            problem.setParam('LogToConsole',0)
+            problem.setParam('Warning',1)
         # add variables
         x = problem.addMVar(shape=self.inputdata.num_vars,lb=self.lb,ub=self.ub,vtype=self.vtypes)
         # x = problem.addMVar(shape=self.inputdata.num_vars,lb=self.lb,ub=self.ub,vtype=['C' for _ in range(self.inputdata.num_vars)])
@@ -243,6 +246,9 @@ class LPMain:
         # nbew empty problem
         problem = cplex.Cplex()
 
+        if self.inputdata.verbose == False:
+            problem.set_log_stream(None)
+            problem.set_results_stream(None)
         # Adding variables
         problem.variables.add(names=['x' + str(i) for i in range(self.inputdata.num_vars)])
 
